// generated from rosidl_generator_c/resource/idl__type_support.h.em
// with input from geometry_msgs:msg/PoseArray.idl
// generated code does not contain a copyright notice

// IWYU pragma: private, include "geometry_msgs/msg/pose_array.h"


#ifndef GEOMETRY_MSGS__MSG__DETAIL__POSE_ARRAY__TYPE_SUPPORT_H_
#define GEOMETRY_MSGS__MSG__DETAIL__POSE_ARRAY__TYPE_SUPPORT_H_

#include "rosidl_typesupport_interface/macros.h"

#include "geometry_msgs/msg/rosidl_generator_c__visibility_control.h"

#ifdef __cplusplus
extern "C"
{
#endif

#include "rosidl_runtime_c/message_type_support_struct.h"

// Forward declare the get type support functions for this type.
ROSIDL_GENERATOR_C_PUBLIC_geometry_msgs
const rosidl_message_type_support_t *
ROSIDL_TYPESUPPORT_INTERFACE__MESSAGE_SYMBOL_NAME(
  rosidl_typesupport_c,
  geometry_msgs,
  msg,
  PoseArray
)();

#ifdef __cplusplus
}
#endif

#endif  // GEOMETRY_MSGS__MSG__DETAIL__POSE_ARRAY__TYPE_SUPPORT_H_
